Module system
async_
ecs
0.1.0
Module system
Module Items
Traits
In crate async_
ecs
async_ecs
Module
system
Traits

Async
System
A
System
, executed with a set of required
Resource
s asynchronous.
Dynamic
System
Data
A struct implementing system data indicates that it bundles some resources which are required for the execution.
System
A
System
, executed with a set of required
Resource
s.
System
Data
A static system data that can specify its dependencies at statically (at compile-time). Most system data is a
SystemData
, the
DynamicSystemData
type is only needed for very special setups.